﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web;
using System.Data;
using System.Xml.Linq;
using GOA.Department.ANS.Web.Model.Interfaces;

namespace GOA.Department.ANS.Web.Model.BusinessAssociates
{
    public class AddressRepository : IAddressRepository
    {
        private string fileName = HttpContext.Current.Server.MapPath("~/App_Data/ba_addr.xml");

        public AddressRepository()
        {
        }

        public IEnumerable<Address> GetAddresses()
        {
            var baData = XDocument.Load(fileName);

            var baList = from ba in baData.Descendants("Address")
                         select new Address
                         {
                             AddressID = Convert.ToInt32(ba.Attribute("BAAddressAddonKey").Value),
                             BAKey = Convert.ToInt32(ba.Attribute("BAKey").Value),
                             Purpose = ba.Attribute("Purpose").Value,
                             AddressDetails = ba.Attribute("AddressLine").Value,
                             City = ba.Attribute("City").Value,
                             Province = ba.Attribute("ProvinceState").Value,
                             Zipcode = ba.Attribute("PostalZipcode").Value,
                             Country = ba.Attribute("Country").Value,
                             Phone = ba.Attribute("BATelephoneNumber").Value,
                             Fax = ba.Attribute("BAFaxNumber").Value,
                             Email = ba.Attribute("BAEmailAddress").Value
                         };
            var bas = new List<Address>();
            bas.AddRange(baList.ToList<Address>());
            return bas;
        }

        public Dictionary<string, string> GetAddressPurposes()
        {
            var baData = new Dictionary<string, string>()
            {
                {"Corporate", "CORPORATE"},
                {"Land_Tenure", "LAND TENURE"},
                {"Mineral_Tax", "MINERAL TAX"},
                {"Surface", "SURFACE"},
                {"Surface1", "SURFACE 1"},
                {"Surface2", "SURFACE 2"},
                {"Surface3", "SURFACE 3"}
            };
            return baData;
        }

        public Tuple<bool, string, int> Add(Address ba)
        {            
            var rand = new Random().Next(5, 9999);
            var xmlSource = XDocument.Load(fileName);
            var xmlElement = xmlSource.Element("BA_ADDRESSES").LastNode;

            //add new element at last
            xmlElement.AddAfterSelf(
                new XElement("Address"
                    , new XAttribute("BAAddressAddonKey", rand)
                    , new XAttribute("BAKey", ba.BAKey)
                    , new XAttribute("Purpose", ba.Purpose)
                    , new XAttribute("AddressLine", ba.AddressDetails)
                    , new XAttribute("City", ba.City)
                    , new XAttribute("ProvinceState", ba.Province)
                    , new XAttribute("PostalZipcode", ba.Zipcode)
                    , new XAttribute("Country", ba.Country)
                    , new XAttribute("BATelephoneNumber", ba.Phone)
                    , new XAttribute("BAFaxNumber", ba.Fax)
                    , new XAttribute("BAEmailAddress", ba.Email)
                    ));
            xmlSource.Save(fileName);
            return Tuple.Create(true, "Record Inserted Successfully", rand);
        }

        public Tuple<bool, string> Edit(Address ba)
        {
            return Tuple.Create(true, "Record Updated Successfully");
        }



    }
}